EMI toolbox v4.0 - EMI: Efficient Model Identification
by Alma Masic, Kris Villez

Website:	http://tinyurl.com/eawag-spike
Contact: 	kris.villez@eawag.ch

This toolbox is a collection of Matlab/Octave functions and scripts written to evaluate tools for efficient model selection and parameter identification. This particular version of the toolbox provides the necessary code to reproduce the results reported in [1-4].

These files are provided as is, with no guarantees and are intended for non-commercial use. These routines have been developed and tested successfully with Matlab (R2014b,R2017b) on a Windows system. Tests in Octave are incomplete at the time of writing. To install the Matlab functions in a Windows system, using Matlab or Octave, follow the instructions below.

---------------------------------------------------
 I. Installing the toolbox and other preliminaries
---------------------------------------------------

1. Create a directory to contain all required toolboxes.  For example, in my case all toolbox directories are in:

		C:\Tools\

2. Move the unzipped EMI folder (in which this README.txt file is located) to the following location:
	
		C:\Tools\EMI\

3. The EMI toolbox includes all other code necessary except for the MOSEK optimization software. This software is necessary to reproduce the results in [2]. The MOSEK optimization software can be downloaded from https://www.mosek.com/ and should be installed according to the provided instructions. To produce the results in [2], MOSEK Version 7.1.0.27 was used.
	
------------------------------------------------------
 II(A). Using the toolbox to reproduce results in [1]
------------------------------------------------------

1. Start Matlab

2. Go the following folder:

		EMI\EMI_Applications\App1_2016_EMS_GlobalParameterEstimation

	and execute the available scripts in the following order:
	
		STEP1B_DemoBounds
		STEP2_Contracting_Plot
		STEP3_BranchAndBound_Plot
		STEP4_GreedyOpt_Plot
	
3. To recompute all results and produce the figures, go the folder:

		EMI\EMI_Applications\App1_2016_EMS_GlobalParameterEstimation

	and execute the available scripts in the following order: 

		STEP1_SetupOptimization
		STEP1B_DemoBounds
		STEP2_Contracting
		STEP2_Contracting_Plot
		STEP3_BranchAndBound
		STEP3_BranchAndBound_Plot

------------------------------------------------------
 II(B). Using the toolbox to reproduce results in [2]
------------------------------------------------------
		
1. Start Matlab

2. Ensure the MOSEK optimization software is installed correctly. Test this by executing the following in the command line

		mosekopt 
		
3. To reproduce the figures, go the following folder:

		EMI\EMI_Applications\App2_2016_CACE_ShapeConstraints

	and execute the script 'MainScript.m' .	
		
3. To recompute all results and produce the figures, then:

	3.1. Go the folder:	EMI\EMI_Applications\App2_2016_CACE_ShapeConstraints
	3.2. Modify 'MainScript.m' by uncommenting line 42
	3.3. Execute the script 'MainScript.m' .
		
----------------------------
 III. Relevant publications
----------------------------

Please refer to this toolbox by citing following publication:
[1] Masic, A., Udert, K., Villez, K. (2016). Global parameter optimization for biokinetic modeling of simple batch experiments. Environmental Modelling and Software, 85, 356-373.
[2] Masic, A., Srinivasan, S., Billeter, J., Bonvin, D., Villez, K. (2016). Shape Constrained Splines as Transparent Black-Box Models for Bioprocess Modeling. Computers and Chemical Engineering, Accepted, In Press.
[3] Masic, A., Udert, K., Villez, K. (2016). Global parameter optimization for biokinetic modeling of simple batch experiments. Environmental Modelling and Software, 85, 356-373. 
[4] Villez, K. Billeter, J., Bonvin, D. (submitted). Incremental parameter estimation under rank-deficient measurement conditions. Submitted to Processes.

Related Eawag publications are the following:
[5] Käempf, G. (2015). Calibration and Validation of the Urine Nitrification Model. Master Thesis, ETHZ, Zürich, Switzerland.
[6] Villez, K., Venkatasubramanian, V., Rengaswamy, R. (2013). Generalized Shape Constrained Spline Fitting for Qualitative Analysis of Trends. Computers & Chemical Engineering, 58, 116-134.
[7] Villez, K., Habermacher, J. (2016). Shape Anomaly Detection for Process Monitoring of a Sequencing Batch Reactor. Computers and Chemical Engineering, 91, 365-379.

-------------
 IV. Changes
-------------

14-10-2016: Integrated the code for dynamic modelling with shape constrained spline functions into the toolbox.
21-12-2016: Removed redundant instances of the Spike_B and Spike_O toolboxes. Modified use of BB.m to match the selected version of the Spike_O toolbox (v1.1). Modified scripts so that installation folder for Mosek is not assumed known. Corrected a path error in STEP4_GreedyOpt.m. Modified this README file to be clearer and complete.
12.12.2018: Integrated code for publication [4] into EMI toolbox

------------------
 Acknowledgements
------------------

We want to thank our partners at EPFL for their assistance in the EMISSUN project, within which this toolbox was developed:
- Dominique Bonvin
- Julien Billeter
- Sriniketh Srinivasan

We want to thank Gabriël Käempf for the experimental work that made the work in [1] possible.

----------------------------------------------------------
Last modified on 12 December 2018